@@ -1,12 +1,14 @@
 __all__ = ['thread',
            'thread_pool',
            'process',
+           #'process_pool',
            'synchronized',
            'ThreadPool',
            'PebbleError',
+           'ProcessPool',
            'TimeoutError',
            'TaskCancelled']
 
 from .pebble import PebbleError, TimeoutError, synchronized
-from .process import process, TaskCancelled
+from .process import ProcessPool, process, TaskCancelled
 from .thread import thread, thread_pool, ThreadPool
